@@ -1,4 +1,4 @@
-# $Id: Alias.pm 46832 2017-08-01 11:08:55Z wsl $
+# $Id: Alias.pm 46898 2017-08-24 11:53:09Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/kiki/lib/UvT/Kiki/Database/Alias.pm $
 
 package UvT::Kiki::Database::Alias;
@@ -236,27 +236,28 @@ sub diff {
 	my $diff = $ab ? "$full (in address book):\n" : "$full (not in address book):\n";
 
 	if(my $old = $self->original) {
-		$ab = $old->addressbook
+		$diff = $old->addressbook
 			? $ab
-				? "in address book"
-				: "no longer in address book"
+				? "$full (in address book)\n"
+				: "$full (no longer in address book)\n"
 			: $ab
-				? "now in address book"
-				: "not in address book";
+				? "$full (now in address book)\n"
+				: "$full (not in address book)\n";
 
-		$diff = "$full ($ab):\n";
-		
 		my %destinations; @destinations{@destinations} = ();
 		my @old_destinations = map { $_->full } @{$old->destinations};
 		my %old_destinations; @old_destinations{@old_destinations} = ();
-		my %all_destinations = (%destinations, %old_destinations);
 
-		foreach my $destination (sort { lc($a) cmp lc($b) || $a cmp $b } keys %all_destinations) {
-			$diff .= exists $destinations{$destination}
-				? exists $old_destinations{$destination}
-					? " \t$destination\n"
-					: "+\t$destination\n"
-				: "-\t$destination\n";
+		foreach my $destination (sort { lc($a) cmp lc($b) || $a cmp $b } @old_destinations) {
+			$diff .= "-\t$destination\n" unless exists $destinations{$destination};
+		}
+
+		foreach my $destination (sort { lc($a) cmp lc($b) || $a cmp $b } @old_destinations) {
+			$diff += " \t$destination\n" if exists $destinations{$destination};
+		}
+
+		foreach my $destination (sort { lc($a) cmp lc($b) || $a cmp $b } @destinations) {
+			$diff += "+\t$destination\n" unless exists $old_destinations{$destination};
 		}
 	} else {
 		foreach my $destination (sort { lc($a) cmp lc($b) || $a cmp $b } @destinations) {
