@@ -1,4 +1,4 @@
-# $Id: Person.pm 46806 2017-07-26 15:48:10Z wsl $
+# $Id: Person.pm 46898 2017-08-24 11:53:09Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/kiki/lib/UvT/Kiki/Database/Person.pm $
 
 package UvT::Kiki::Database::Person;
@@ -174,39 +174,37 @@ sub expand { return }
 # A textual representation of how this entry is different from an older version.
 # If no older version is available, a pseudo-diff is generated.
 sub diff {
-	my $full = $self->full;
-	my $anr = $self->anr;
 	my @labels = map { $_->full } @{$self->labels};
+	my $full = shift @labels;
+	my $anr = $self->anr;
+
 	my $diff = "$full ($anr):\n";
 
 	if(my $old = $self->original) {
-		my $old_full = $old->full;
-		$full = "$full => $old_full" if $full ne $old_full;
-
+		my @old_labels = map { $_->full } @{$old->labels};
+		my $old_full = shift @old_labels;
 		my $old_anr = $old->anr;
-		$anr = "$old_anr => $anr" if $old_anr != $anr;
-
-		$diff = "$full ($anr):\n";
 
 		my %labels; @labels{@labels} = ();
-		my @old_labels = map { $_->full } @{$old->labels};
 		my %old_labels; @old_labels{@old_labels} = ();
-		my %all_labels = (%labels, %old_labels);
 
-		# make sure we don't include the primary address, it's already in the header
-		delete @all_labels{$full, $old_full};
+		my $full_text = $full eq $old_full ? $full : "$full => $old_full";
+		my $anr_text = $old_anr == $anr ? $anr : "$old_anr => $anr";
 
-		foreach my $label (sort { lc($a) cmp lc($b) || $a cmp $b } keys %all_labels) {
-			$diff .= exists $labels{$label}
-				? exists $old_labels{$label}
-					? " \t$label\n"
-					: "+\t$label\n"
-				: "-\t$label\n";
+		$diff = "$full_text ($anr_text):\n";
+
+		foreach my $label (sort { lc($a) cmp lc($b) || $a cmp $b } @old_labels) {
+			$diff .= "-\t$label\n" unless exists $labels{$label};
+		}
+
+		foreach my $label (sort { lc($a) cmp lc($b) || $a cmp $b } @old_labels) {
+			$diff .= " \t$label\n" if exists $labels{$label};
+		}
+
+		foreach my $label (sort { lc($a) cmp lc($b) || $a cmp $b } @labels) {
+			$diff .= "+\t$label\n" unless exists $old_labels{$label};
 		}
 	} else {
-		# make sure we don't include the primary address, it's already in the header
-		shift @labels;
-
 		foreach my $label (sort { lc($a) cmp lc($b) || $a cmp $b } @labels) {
 			next if $label eq $full;
 			$diff .= " \t$label\n";
