@@ -1,4 +1,4 @@
-# $Id: Request.pm 37340 2012-07-02 17:27:19Z wsl $
+# $Id: Request.pm 40187 2013-09-17 13:35:51Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/kiki/lib/UvT/Kiki/UI/Request.pm $
 
 use strict;
@@ -22,7 +22,7 @@ field lang => sub {
 		}
 	}
 
-	my $h = lc($self->http('Accept-Language'));
+	my $h = lc($self->http('Accept-Language') // '');
 	$h =~ s/\s//g;
 
 	my $curlang = $supported[0];
